/// @addtogroup cymealg
/// @{

/////////////////////////////////////////////////////////////////////////////
///
/// @file
///
/// This file contains the definition of a class for rounding operations
/// for graph algorithms, based on the BOOST library.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2020 by Pawel Pilarczyk.
//
// This file is part of my research software. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <http://www.gnu.org/licenses/>.

// Started in January 2006. Last revision: August 23, 2019.


#ifndef _CYMEALG_BOOSTRND_H_
#define _CYMEALG_BOOSTRND_H_

// BOOST (this header must be included first)
#include "boost/numeric/interval.hpp"

namespace cymealg {

// --------------------------------------------------
// -------------------- rounding --------------------
// --------------------------------------------------

/// A class for rounding operations which uses the BOOST library.
template <class numType>
class tBoostRounding
{
public:
/// This is an internal macro of the class template "tBoostRounding"
/// which defines arithmetic operations using the operations
/// available in the BOOST library.
#define DEFOP(WHAT) \
	static inline numType WHAT (const numType &x, const numType &y) \
	{ \
		numType result = Rounding. WHAT (x, y); \
		Rounding. to_nearest (); \
		return result; \
	}

	DEFOP(add_down)
	DEFOP(add_up)
	DEFOP(sub_down)
	DEFOP(sub_up)
	DEFOP(mul_down)
	DEFOP(mul_up)
	DEFOP(div_down)
	DEFOP(div_up)

#undef DEFOP

/*	numType add_down (const numType &x, const numType &y) const
	{
		numType result = Rounding. add_down (x, y);
		Rounding. to_nearest ();
		return result;
	}
*/

private:
	/// This is an object from the BOOST library which contains
	/// the definitions of arithmetic operations with correct rounding.
	static boost::numeric::interval_lib::rounded_arith_std<numType>
		Rounding;
}; /* class tBoostRounding */

// --------------------------------------------------

template <class numType>
boost::numeric::interval_lib::rounded_arith_std<numType>
	tBoostRounding<numType>::Rounding;


} // namespace cymealg

#endif // _CYMEALG_BOOSTRND_H_

/// @}

