/// @addtogroup cymealg
/// @{

/////////////////////////////////////////////////////////////////////////////
///
/// @file
///
/// This header file contains the definition of a dummy rounding class.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2020 by Pawel Pilarczyk.
//
// This file is part of my research software. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <http://www.gnu.org/licenses/>.

// Started in January 2006. Last revision: August 23, 2019.


#ifndef _CYMEALG_DUMMYRND_H_
#define _CYMEALG_DUMMYRND_H_

namespace cymealg {

// --------------------------------------------------
// ----------------- DUMMY ROUNDING -----------------
// --------------------------------------------------

/// A dummy class for rounding operations which does not actually do
/// any rounding. Please, use it as a template for your own rounding classes.
template <class numType>
class dummyRounding
{
public:
	/// Adds two numbers with the result rounded downwards.
	static inline numType add_down (const numType &x, const numType &y)
	{ return x + y; }

	/// Adds two numbers with the result rounded upwards.
	static inline numType add_up (const numType &x, const numType &y)
	{ return x + y; }

	/// Subtracts two numbers with the result rounded downwards.
	static inline numType sub_down (const numType &x, const numType &y)
	{ return x - y; }

	/// Subtracts two numbers with the result rounded upwards.
	static inline numType sub_up (const numType &x, const numType &y)
	{ return x - y; }

	/// Multiplies two numbers with the result rounded downwards.
	static inline numType mul_down (const numType &x, const numType &y)
	{ return x * y; }

	/// Multiplies two numbers with the result rounded upwards.
	static inline numType mul_up (const numType &x, const numType &y)
	{ return x * y; }

	/// Divides two numbers with the result rounded downwards.
	static inline numType div_down (const numType &x, const numType &y)
	{ return x / y; }

	/// Divides a number by an integer with the result rounded downwards.
	static inline numType div_down (const numType &x, int_t y)
	{ return x / y; }

	/// Divides two numbers with the result rounded upwards.
	static inline numType div_up (const numType &x, const numType &y)
	{ return x / y; }

private:
}; /* class dummyRounding */


} // namespace cymealg

#endif // _CYMEALG_DUMMYRND_H_

/// @}

