/// @addtogroup cymealg
/// @{

/////////////////////////////////////////////////////////////////////////////
///
/// @file
///
/// This header file contains a procedure for computing the subgraph
/// of a directed graph.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2020 by Pawel Pilarczyk.
//
// This file is part of my research software. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <http://www.gnu.org/licenses/>.

// Started in January 2006. Last revision: August 23, 2019.


#ifndef _CYMEALG_SUBGRAPH_H_
#define _CYMEALG_SUBGRAPH_H_

// include selected header files from the CHomP library
#include "chomp/system/config.h"

namespace cymealg {

/// Computes a restriction of the graph to its subgraph. The subgraph
/// vertices are defined by nonzero entries in the supplied table.
/// The result must be initially empty.
template <class Graph1, class Graph2, class Table>
void subgraph (const Graph1 &g, Graph2 &result, const Table &tab,
	bool copyweights = false)
{
	g. subgraph (result, tab, copyweights);
	return;
} /* subgraph */


} // namespace cymealg

#endif // _CYMEALG_SUBGRAPH_H_

/// @}

