/////////////////////////////////////////////////////////////////////////////
///
/// \file
///
/// The main page for the source code documentation.
///
/////////////////////////////////////////////////////////////////////////////
/**

\mainpage


\section intro Introduction

This piece of software contains an implementation of a few graph algorithms,
and is mainly focused on demonstrating a new memory efficient version
of Karp's algorithm for the computation of minimum mean cycle weight
in a directed graph.


\section compilation Compilation

The compilation of the software should be relatively simple.
The GNU C++ compiler should be used.
The Boost library collection should be present in the system.
Please, edit the file <em>makefile</em>
in the directory into which the source code has been unpacked,
one run the command <em>make</em>.
Although this software uses parts of
the <a href="http://chomp.rutgers.edu/software/">CHomP library</a>,
all the relevant files have been included in this distribution,
so it is not necessary to download or compile it first.

In Linux, all the necessary utilities
should be present in the system by default
(the GNU C++ compiler and the GNU make),
but in Windows one should install them first (e.g. from the
<a href="http://www.bloodshed.net/dev/devcpp.html">Dev-C++</a>
distribution).
For convenience, pre-compiled binary programs for some systems
may be provided at the project website.


\section library Software Library

The main part of this software is provided in terms
of a C++ library, programmed as templates of classes
and functions for optimal flexibility
(so-called generic programming technique).
All the header files of which the programming library consists
are located in the subdirectory <em>cymealg</em>.


\section program Test Program

A simple command-line driven program is provided for testing purposes.
The program displays brief usage information
when called without arguments.
The program reads data from a file in the text format
and displays all the results to the output stream,
which is the screen by default,
but can also be logged to a file using the "--log filename"
command-line argument.


\section data Data Format

A graph in the text format is stored in an intuitive way.
The vertices of the graph are assumed to be labeled
by consecutive integers, starting with 0.
The number of vertices in the graph is determined automatically
if there exists an outgoing edge from the vertex
with the higher number; otherwise it must be given explicitly.
Arcs are defined by the numbers of vertices
separated with an arrow bulit from the dash
and the "greater than" character.
Weights of each edge are provided in brackets
after the definition of each arc.
All text that begins with a semicolon is ignored
until the end of the line.
For example:

<pre>
; This is a sample graph.
4 vertices
0 -> 0 [1.12]
0 -> 1 [2.33]
1 -> 0 [-1e-6]
2 -> 0 [14]
</pre>

\section examples Examples

A selection of sample graphs are included in a separate file,
available for download from project's website.
Please, be warned that processing some of the larger examples
may require considerable resources (memory, CPU time).


\section license License

This software package is published under the terms
of the <a href="http://www.gnu.org/licenses/gpl.html">GNU
General Public License, version 3</a>.


\section remark Remarks

Although many classes and functions already have their descriptions,
I am aware of the fact that these descriptions are not as detailed
as the user might wish to have. Therefore, this documentation
has been generated in such a way that it includes the entire source code
which sould be consulted if in doubt. The code has many additional
comments which shed light on what it actually does.

Therefore, I apologize for any inconvenience caused by the incomplete
documentation and I invite to browse the source code instead,
or ask me specific questions by email.

Pawel Pilarczyk

**/
